<?php
/**
 * Theme options selected from customizer
 *
 * @package spiffy-lite
 * @subpackage functions
 * @since Spiffy Lite 1.0.0
 */

if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly.
}

/**
 * Function to init jetpack functionality
 */
function spiffy_lite_jetpack_setup() {

	add_theme_support( 'automatic-feed-links' );
	add_theme_support( 'nova_menu_item' );

	// Add support for featured content on homepage.
	add_theme_support( 'featured-content', array(
		'filter'     => 'spiffy_lite_get_featured_posts',
		'max_posts'  => 20,
		'post_types' => array( 'post', 'page' ),
	) );

	$posts_per_page = get_option( 'posts_per_page' );
	// Add support for Jetpack infinite-scroll.
	add_theme_support( 'infinite-scroll', array(
		'container'      => 'spiffy-infinite-content',
		'render'         => 'spiffy_lite_infinite_render',
		'posts_per_page' => $posts_per_page ? $posts_per_page : false,
		'footer_widgets' => false,
	) );
}
add_action( 'after_setup_theme', 'spiffy_lite_jetpack_setup' );

/**
 * Function to override read more test
 */
function spiffy_lite_infinite_render() {
	get_template_part( 'template-parts/posts-display-classic' );
}

/**
 * Function to get nova menu sections
 *
 * @param int $post_id .
 */
function spiffy_lite_get_menu_item_menu_leaf( $post_id ) {
	$terms = get_the_terms( $post_id, Nova_Restaurant::MENU_TAX );
	$term_ids = wp_list_pluck( $terms, 'term_id' );

	if ( is_array( $term_ids ) && count( $term_ids ) ) {
		foreach ( $term_ids as $term_id ) {
			$children = get_term_children( $term_id, Nova_Restaurant::MENU_TAX );
			if ( ! $children ) {
				break;
			}
		}
	}

	if ( ! isset( $term_id ) ) {
		return false;
	}

	return get_term( $term_id, Nova_Restaurant::MENU_TAX );

}

/**
 * Function to get nova menu terms
 *
 * @param int $post_id .
 */
function spiffy_lite_get_menu_item_terms( $post_id ) {
	if ( intval( $post_id ) ) {
		$terms = get_the_terms( $post_id, Nova_Restaurant::MENU_ITEM_LABEL_TAX );
		if ( ! empty( $terms ) ) :
			foreach ( $terms as $term ) :
				$term_name = $term->name;
				$term_slug = $term->slug;
				echo '<span class="' . esc_attr( $term_slug ) . '">' . esc_html( $term_name ) . '</span>';
			endforeach;
		endif;
	}
}

/**
 * Getter function for Featured Content Plugin.
 *
 * @return array An array of WP_Post objects.
 */
function spiffy_lite_get_featured_posts() {
	/**
	 * Filter the featured posts
	 *
	 * @param array|bool $posts Array of featured posts, otherwise false.
	 */
	return apply_filters( 'spiffy_lite_get_featured_posts', array() );
}
