<?php
/**
 * Theme options selected from customizer
 *
 * @package spiffy-lite
 * @subpackage functions
 * @since Spiffy Lite 1.0.0
 */

if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly.
}

if ( ! function_exists( 'spiffy_lite_google_fonts_url' ) ) {
	/**
	 * Load google fonts
	 */
	function spiffy_lite_google_fonts_url() {
		$fonts_url = '';

		$josefin_sans = _x( 'on', 'Josefin Sans font: on or off', 'spiffy-lite' );

		$maven_pro = _x( 'on', 'Maven Pro font: on or off', 'spiffy-lite' );

		if ( 'off' !== $josefin_sans || 'off' !== $maven_pro ) {
			$font_families = array();

			if ( 'off' !== $josefin_sans ) {
				$font_families[] = 'Josefin Sans:100,300,400,700';
			}

			if ( 'off' !== $maven_pro ) {
				$font_families[] = 'Maven Pro';
			}

			$query_args = array(
				'family' => rawurlencode( implode( '|', $font_families ) ),
			);

			$fonts_url = add_query_arg( $query_args, 'https://fonts.googleapis.com/css' );
		}

		return esc_url_raw( $fonts_url );
	}
}

if ( ! function_exists( 'spiffy_lite_scripts_styles' ) ) {
	/**
	 * Load google fonts
	 */
	function spiffy_lite_scripts_styles() {
		wp_enqueue_style( 'spiffy-lite-fonts', spiffy_lite_google_fonts_url(), array(), null );
	}
	add_action( 'wp_enqueue_scripts', 'spiffy_lite_scripts_styles' );
}

if ( ! function_exists( 'spiffy_lite_get_theme_mod' ) ) {

	/**
	 * Get customizer options
	 *
	 * @param string $section .
	 */
	function spiffy_lite_get_theme_mod( $section = null ) {
		$spiffy_option = get_theme_mod( $section );
		return $spiffy_option;
	}
}

if ( ! function_exists( 'spiffy_lite_customizer_live_preview' ) ) {
	/**
	 * Used by hook: 'customize_preview_init'
	 *
	 * @see add_action('customize_preview_init',$func)
	 */
	function spiffy_lite_customizer_live_preview() {
		wp_enqueue_script(
			'spiffy-lite-customizer',
			get_template_directory_uri() . '/assets/js/scripts-customizer.js',
			array( 'jquery', 'customize-preview' ),
			'1.0.0',
			true
		);
	}
	add_action( 'customize_preview_init', 'spiffy_lite_customizer_live_preview' );
}

if ( ! function_exists( 'spiffy_lite_override_read_more' ) ) {
	/**
	 * Function to override read more test
	 *
	 * @param mixed $more .
	 */
	function spiffy_lite_override_read_more( $more ) {
		global $post;
		return ' <span class="spf-read-more"><a class="spf-link-more" href="' . esc_url( get_permalink( $post->ID ) ) . '" title="' . esc_attr__( 'Read more', 'spiffy-lite' ) . get_the_title( $post->ID ) . '">' . esc_html__( 'Read more', 'spiffy-lite' ) . '</a></span>';
	}
	add_filter( 'excerpt_more', 'spiffy_lite_override_read_more' );
}

if ( ! function_exists( 'spiffy_lite_display_breadcrumbs' ) ) {
	/**
	 * Function to override read more test
	 */
	function spiffy_lite_display_breadcrumbs() {
		global $post;
		if ( is_single() || is_page() ) {
			echo '<div class="spf-breadcrumbs">';
			echo '<span class="screen-reader-text">' . esc_html__( 'Page breadcrumbs', 'spiffy-lite' ) . '</span>';
			echo '<ul id="breadcrumbs">';
			if ( ! is_home() ) {
				if ( is_single() ) {
					echo '<li class="spf-home-breadcrumb"><a href="';
					echo esc_html( home_url() );
					echo '" class="dashicons dashicons-admin-home">';
					echo '</a></li><li class="separator"> / </li>';
	                the_title();
	                echo '</li>';
				} elseif ( is_page() ) {
					if ( $post->post_parent ) {
						echo '<li class="spf-home-breadcrumb"><a href="';
						echo esc_html( home_url() );
						echo '" class="dashicons dashicons-admin-home">';
						echo '</a></li><li class="separator"> / </li>';
						$anc = get_post_ancestors( $post->ID );
						$title = get_the_title();
						foreach ( $anc as $ancestor ) {
							echo '<li><a href="' . esc_url( get_permalink( $ancestor ) ) . '" title="' . esc_attr( get_the_title( $ancestor ) ) . '">' . get_the_title( $ancestor ) . '</a></li> <li class="separator">/</li>';
						}
						echo '<span title="' . esc_attr( $title ) . '"> ' . esc_html( $title ) . '</span>';
					} else {
						echo '<li class="spf-home-breadcrumb"><a href="';
						echo esc_html( home_url() );
						echo '" class="dashicons dashicons-admin-home">';
						echo '</a></li><li class="separator"> / </li>';
						echo '<li><span> ' . get_the_title() . '</span></li>';
					}
				}
			} elseif ( is_tag() ) {
				single_tag_title();
			} elseif ( is_day() ) {
				echo '<li>Archive for ';
				the_time( 'F jS, Y' );
				echo '</li>';
			} elseif ( is_month() ) {
				echo '<li>Archive for ';
				the_time( 'F, Y' );
				echo '</li>';
			} elseif ( is_year() ) {
				echo '<li>Archive for ';
				the_time( 'Y' );
				echo '</li>';
			} elseif ( is_author() ) {
				echo '<li>Author Archive';
				echo '</li>';
			} elseif ( isset( $_GET['paged'] ) && ! empty( $_GET['paged'] ) ) {
				echo '<li>Blog Archives';
				echo'</li>';
			} elseif ( is_search() ) {
				echo '<li>Search Results';
				echo '</li>';
			}
			echo '</ul>';
			echo '<span class="screen-reader-text">' . esc_html__( 'End of page breadcrumbs', 'spiffy-lite' ) . '</span>';
			echo '</div>';
		}
	}
}
